/*
 * DPharp HART Device Description Header File
 *
 *	Yokogawa Electric Corporation
 *
 *	Change notes: (File name, Date, Name, Description)
 * =========================================================================
 *  dpharp_common_macro.h	2010-10-19	Y. Kawasaki		New
 *  dpharp_common_macro.h	2011-01-17	G. Ou           Add for method of ChgUnivRev. 
 *                                                          and method of PowerOnInfo
 *
 */

/* Pressure unit code number */
#define	PRESS_UNIT_CODE_INH2O_68DEGF		1
#define	PRESS_UNIT_CODE_INHG				2
#define	PRESS_UNIT_CODE_FTH2O_68DEGF		3
#define	PRESS_UNIT_CODE_MMH2O_68DEGF		4
#define	PRESS_UNIT_CODE_MMHG				5
#define	PRESS_UNIT_CODE_PSI					6
#define	PRESS_UNIT_CODE_BAR					7
#define	PRESS_UNIT_CODE_MBAR				8
#define	PRESS_UNIT_CODE_GCM2				9
#define	PRESS_UNIT_CODE_KGCM2				10
#define	PRESS_UNIT_CODE_PA					11
#define	PRESS_UNIT_CODE_KPA					12
#define	PRESS_UNIT_CODE_TORR				13
#define	PRESS_UNIT_CODE_ATM					14
#define	PRESS_UNIT_CODE_MPA					237
#define	PRESS_UNIT_CODE_INH2O_4DEGC			238
#define	PRESS_UNIT_CODE_MMH2O_4DEGC			239
/* Define it individually						 */
/*	PRESS_UNIT_CODE_FTH2O_4DEGC	240 or 177?	*/
/*	PRESS_UNIT_CODE_HPA			241 or 174?	*/


#define PRESSURE_PRECISION  SELECT (p_range_code) { \
	CASE 0: 		/*	M range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".3f";		/* inH2O  @ 68degF */ \
		CASE	PRESS_UNIT_CODE_INHG: 			".4f";		/* inHg  @ 0degC */ \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".4f";		/* ftH2O  @ 68degF */ \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".1f";		/* mmH2O @ 68degF */ \
		CASE	PRESS_UNIT_CODE_MMHG: 			".2f";		/* mmHg @ 0degC */ \
		CASE	PRESS_UNIT_CODE_PSI: 			".4f";		/* psi */ \
		CASE	PRESS_UNIT_CODE_BAR: 			".5f";		/* bar */ \
		CASE	PRESS_UNIT_CODE_MBAR: 			".2f";		/* mbar */ \
		CASE	PRESS_UNIT_CODE_GCM2: 			".2f";		/* g/cm2 */ \
		CASE	PRESS_UNIT_CODE_KGCM2: 			".5f";		/* kg/cm2 */ \
		CASE	PRESS_UNIT_CODE_PA: 			".0f";		/* Pa */ \
		CASE	PRESS_UNIT_CODE_KPA: 			".3f";		/* kPa */ \
		CASE	PRESS_UNIT_CODE_TORR: 			".2f";		/* torr */ \
		CASE	PRESS_UNIT_CODE_ATM: 			".5f";		/* atm */ \
		CASE	PRESS_UNIT_CODE_MPA:		 	".6f";		/* MPa */ \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC: 	".3f";		/* inH2O @ 4degC */ \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".1f";		/* mmH2O @ 4degC */ \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC: 	".4f";		/* ftH2O @ 4degC */ \
		CASE	PRESS_UNIT_CODE_HPA: 			".2f";		/* hPa */ \
		DEFAULT:	".4f"; \
	} \
	CASE 1: 		/*	H range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".3f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".3f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".2f"; \
		CASE	PRESS_UNIT_CODE_PSI:			".3f"; \
		CASE	PRESS_UNIT_CODE_BAR:			".4f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".1f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".1f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".4f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:			".2f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".2f"; \
		CASE	PRESS_UNIT_CODE_ATM:			".4f"; \
		CASE	PRESS_UNIT_CODE_MPA:			".5f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".3f"; \
		CASE	PRESS_UNIT_CODE_HPA:			".1f"; \
		DEFAULT:	".4f"; \
	} \
	CASE 2: 		/*	L range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".3f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".5f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".4f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".3f"; \
		CASE	PRESS_UNIT_CODE_PSI:			".5f"; \
		CASE	PRESS_UNIT_CODE_BAR:			".6f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".3f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".3f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".6f"; \
		CASE	PRESS_UNIT_CODE_PA:				".1f"; \
		CASE	PRESS_UNIT_CODE_KPA:			".4f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".3f"; \
		CASE	PRESS_UNIT_CODE_ATM:			".6f"; \
		CASE	PRESS_UNIT_CODE_MPA:			".6f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".3f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".2f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".4f"; \
		CASE	PRESS_UNIT_CODE_HPA:			".3f"; \
		DEFAULT:	".4f"; \
	} \
	CASE 3: 		/*	A range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".3f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".3f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".1f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".2f"; \
		CASE	PRESS_UNIT_CODE_PSI:			".2f"; \
		CASE	PRESS_UNIT_CODE_BAR:			".5f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".2f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".2f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".5f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:			".3f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".2f"; \
		CASE	PRESS_UNIT_CODE_ATM:			".5f"; \
		CASE	PRESS_UNIT_CODE_MPA:			".6f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".1f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".3f"; \
		CASE	PRESS_UNIT_CODE_HPA:			".2f"; \
		DEFAULT:	".4f"; \
	} \
	CASE 4: 		/*	B range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".1f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".3f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".1f"; \
		CASE	PRESS_UNIT_CODE_PSI:			".3f"; \
		CASE	PRESS_UNIT_CODE_BAR:			".4f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".1f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".1f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".4f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:			".2f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".1f"; \
		CASE	PRESS_UNIT_CODE_ATM:			".4f"; \
		CASE	PRESS_UNIT_CODE_MPA:			".5f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".1f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".2f"; \
		CASE	PRESS_UNIT_CODE_HPA:			".1f"; \
		DEFAULT:	".3f"; \
	} \
	CASE 5: 		/*	C range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".2f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".0f"; \
		CASE	PRESS_UNIT_CODE_PSI:			".2f"; \
		CASE	PRESS_UNIT_CODE_BAR:			".3f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".0f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".0f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".3f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:			".1f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".0f"; \
		CASE	PRESS_UNIT_CODE_ATM:			".3f"; \
		CASE	PRESS_UNIT_CODE_MPA:			".4f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".2f"; \
		CASE	PRESS_UNIT_CODE_HPA:			".0f"; \
		DEFAULT:	".2f"; \
	} \
	CASE 6: 		/*	E range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".4f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".5f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".5f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".4f"; \
		CASE	PRESS_UNIT_CODE_PSI:			".5f"; \
		CASE	PRESS_UNIT_CODE_BAR:			".6f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".3f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".3f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".6f"; \
		CASE	PRESS_UNIT_CODE_PA:				".1f"; \
		CASE	PRESS_UNIT_CODE_KPA:			".4f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".4f"; \
		CASE	PRESS_UNIT_CODE_ATM:			".6f"; \
		CASE	PRESS_UNIT_CODE_MPA:			".6f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".4f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".2f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".5f"; \
		CASE	PRESS_UNIT_CODE_HPA:			".3f"; \
		DEFAULT:	".4f"; \
	} \
	CASE 7: 		/*	V range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".1f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".2f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".0f"; \
		CASE	PRESS_UNIT_CODE_PSI:			".2f"; \
		CASE	PRESS_UNIT_CODE_BAR:			".3f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".0f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".0f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".3f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:			".1f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".0f"; \
		CASE	PRESS_UNIT_CODE_ATM:			".3f"; \
		CASE	PRESS_UNIT_CODE_MPA:			".4f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".1f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".2f"; \
		CASE	PRESS_UNIT_CODE_HPA:			".0f"; \
		DEFAULT:	".3f"; \
	} \
	CASE 8: 		/*	D range		*/ \
	SELECT( pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".1f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".1f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".0f"; \
		CASE	PRESS_UNIT_CODE_PSI:			".1f"; \
		CASE	PRESS_UNIT_CODE_BAR:			".2f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".0f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".0f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".2f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:			".0f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".0f"; \
		CASE	PRESS_UNIT_CODE_ATM:			".2f"; \
		CASE	PRESS_UNIT_CODE_MPA:			".3f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".1f"; \
		CASE	PRESS_UNIT_CODE_HPA:			".0f"; \
		DEFAULT:	".3f"; \
	} \
	DEFAULT:	".4f";\
}\

#define EDIT_PRESSURE_PRECISION PRESSURE_PRECISION

#define SPRESSURE_PRECISION  SELECT( static_pressure_units ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".1f";		/* inH2O  @ 68degF */ \
		CASE	PRESS_UNIT_CODE_INHG:			".2f";		/* inHg  @ 0degC */ \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".2f";		/* ftH2O  @ 68degF */ \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f";		/* mmH2O @ 68degF */ \
		CASE	PRESS_UNIT_CODE_MMHG:			".0f";		/* mmHg @ 0degC */ \
		CASE	PRESS_UNIT_CODE_PSI:			".2f";		/* psi */ \
		CASE	PRESS_UNIT_CODE_BAR:			".3f";		/* bar */ \
		CASE	PRESS_UNIT_CODE_MBAR:			".0f";		/* mbar */ \
		CASE	PRESS_UNIT_CODE_GCM2:			".0f";		/* g/cm2 */ \
		CASE	PRESS_UNIT_CODE_KGCM2:			".3f";		/* kg/cm2 */ \
		CASE	PRESS_UNIT_CODE_PA:				".0f";		/* Pa */ \
		CASE	PRESS_UNIT_CODE_KPA:			".1f";		/* kPa */ \
		CASE	PRESS_UNIT_CODE_TORR:			".0f";		/* torr */ \
		CASE	PRESS_UNIT_CODE_ATM:			".3f";		/* atm */ \
		CASE	PRESS_UNIT_CODE_MPA:			".4f";		/* MPa */ \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:	".1f";		/* inH2O @ 4degC */ \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:	".0f";		/* mmH2O @ 4degC */ \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:	".2f";		/* ftH2O @ 4degC */ \
		CASE	PRESS_UNIT_CODE_HPA:			".0f";		/* hPa */ \
		DEFAULT:	".4f"; \
}\

#define EDIT_SPRESSURE_PRECISION SPRESSURE_PRECISION

#define PRESSURE_UNIT_CODES	\
		{	PRESS_UNIT_CODE_INH2O_68DEGF,	"inH2O @68degF",	[inches_of_water_68_degrees_F_help]},	\
		{	PRESS_UNIT_CODE_INHG,			[InHg],				[inches_of_mercury_0_degrees_C_help]},	\
		{	PRESS_UNIT_CODE_FTH2O_68DEGF,	"ftH2O @68degF",	[feet_of_water_68_degrees_F_help]},	\
		{	PRESS_UNIT_CODE_MMH2O_68DEGF,	"mmH2O @68degF",	[millimeters_of_water_68_degrees_F_help]},	\
		{	PRESS_UNIT_CODE_MMHG,			[mmHg],				[millimeters_of_mercury_0_degrees_C_help]},	\
		{	PRESS_UNIT_CODE_PSI,			[psi],				[pounds_per_square_inch_help]},	\
		{	PRESS_UNIT_CODE_BAR,			[bar],				[bars_help]},	\
		{	PRESS_UNIT_CODE_MBAR,			[mbar],				[millibars_help]},	\
		{	PRESS_UNIT_CODE_GCM2,			"g/cm2",			[grams_per_square_centimeter_help]},	\
		{	PRESS_UNIT_CODE_KGCM2,			"kg/cm2",			[kilograms_per_square_centimeter_help]},	\
		{	PRESS_UNIT_CODE_PA,				[PA],				[pascals_help]},	\
		{	PRESS_UNIT_CODE_KPA,			[kPA],				[kilopascals_help]},	\
		{	PRESS_UNIT_CODE_TORR,			[torr],				[torr_help]},	\
		{	PRESS_UNIT_CODE_ATM,			[ATM],				[atmospheres_help]},	\
		{	PRESS_UNIT_CODE_MPA,			[mega_pascals],		[megapascals_help]},	\
		{	PRESS_UNIT_CODE_INH2O_4DEGC,	[InH2O],			[inches_of_water_4_degrees_C_help]},	\
		{	PRESS_UNIT_CODE_MMH2O_4DEGC,	[mmH2O],			[millimeters_of_water_4_degrees_C_help]},	\
		{	PRESS_UNIT_CODE_FTH2O_4DEGC,	"ftH2O",			"Feet of Water at 4 Degrees Celsius"},	\
		{	PRESS_UNIT_CODE_HPA,			"hPa",				"Hectopascals"}

#define SI_PRESSURE_UNIT_CODES	\
		{	PRESS_UNIT_CODE_BAR,			[bar],				[bars_help]},	\
		{	PRESS_UNIT_CODE_MBAR,			[mbar],				[millibars_help]},	\
		{	PRESS_UNIT_CODE_PA,				[PA],				[pascals_help]},	\
		{	PRESS_UNIT_CODE_KPA,			[kPA],				[kilopascals_help]},	\
		{	PRESS_UNIT_CODE_ATM,			[ATM],				[atmospheres_help]},	\
		{	PRESS_UNIT_CODE_MPA,			[mega_pascals],		[megapascals_help]},	\
		{	PRESS_UNIT_CODE_HPA,			"hPa",				"Hectopascals"}


#define SIM_PRESSURE_PRECISION  SELECT( p_range_code ) { \
	CASE 0: 		/* M range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".3f";		/* inH2O @ 68degF */ \
		CASE	PRESS_UNIT_CODE_INHG:			".4f";		/* inHg @ 0degC */ \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".4f";		/* ftH2O @ 68degF */ \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".1f";		/* mmH2O @ 68degF */ \
		CASE	PRESS_UNIT_CODE_MMHG:			".2f";		/* mmHg @ 0degC */ \
		CASE	PRESS_UNIT_CODE_PSI:				".4f";		/* psi */ \
		CASE	PRESS_UNIT_CODE_BAR:				".5f";		/* bar */ \
		CASE	PRESS_UNIT_CODE_MBAR:			".2f";		/* mbar */ \
		CASE	PRESS_UNIT_CODE_GCM2:			".2f";		/* g/cm2 */ \
		CASE	PRESS_UNIT_CODE_KGCM2:			".5f";		/* kg/cm2 */ \
		CASE	PRESS_UNIT_CODE_PA:				".0f";		/* Pa */ \
		CASE	PRESS_UNIT_CODE_KPA:				".3f";		/* kPa */ \
		CASE	PRESS_UNIT_CODE_TORR:			".2f";		/* torr */ \
		CASE	PRESS_UNIT_CODE_ATM:				".5f";		/* atm */ \
		CASE	PRESS_UNIT_CODE_MPA:				".6f";		/* MPa */ \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".3f";		/* inH2O */ \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".1f";		/* mmH2O */ \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".4f";		/* ftH2O */ \
		CASE	PRESS_UNIT_CODE_HPA:				".2f";		/* hPa */ \
		DEFAULT:	".4f"; \
	} \
	CASE 1: 		/* H range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".3f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".3f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".2f"; \
		CASE	PRESS_UNIT_CODE_PSI:				".3f"; \
		CASE	PRESS_UNIT_CODE_BAR:				".4f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".1f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".1f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".4f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:				".2f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".2f"; \
		CASE	PRESS_UNIT_CODE_ATM:				".4f"; \
		CASE	PRESS_UNIT_CODE_MPA:				".5f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".3f"; \
		CASE	PRESS_UNIT_CODE_HPA:				".1f"; \
		DEFAULT:	".4f"; \
	} \
	CASE 2: 		/* L range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".3f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".5f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".4f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".3f"; \
		CASE	PRESS_UNIT_CODE_PSI:				".5f"; \
		CASE	PRESS_UNIT_CODE_BAR:				".6f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".3f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".3f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".6f"; \
		CASE	PRESS_UNIT_CODE_PA:				".1f"; \
		CASE	PRESS_UNIT_CODE_KPA:				".4f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".3f"; \
		CASE	PRESS_UNIT_CODE_ATM:				".6f"; \
		CASE	PRESS_UNIT_CODE_MPA:				".6f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".3f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".2f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".4f"; \
		CASE	PRESS_UNIT_CODE_HPA:				".3f"; \
		DEFAULT:	".4f"; \
	} \
	CASE 3: 		/* A range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".3f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".3f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".1f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".2f"; \
		CASE	PRESS_UNIT_CODE_PSI:				".2f"; \
		CASE	PRESS_UNIT_CODE_BAR:				".5f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".2f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".2f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".5f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:				".3f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".2f"; \
		CASE	PRESS_UNIT_CODE_ATM:				".5f"; \
		CASE	PRESS_UNIT_CODE_MPA:				".6f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".1f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".3f"; \
		CASE	PRESS_UNIT_CODE_HPA:				".2f"; \
		DEFAULT:	".4f"; \
	} \
	CASE 4: 		/* B range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".1f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".3f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".1f"; \
		CASE	PRESS_UNIT_CODE_PSI:				".3f"; \
		CASE	PRESS_UNIT_CODE_BAR:				".4f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".1f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".1f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".4f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:				".2f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".1f"; \
		CASE	PRESS_UNIT_CODE_ATM:				".4f"; \
		CASE	PRESS_UNIT_CODE_MPA:				".5f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".1f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".2f"; \
		CASE	PRESS_UNIT_CODE_HPA:				".1f"; \
		DEFAULT:	".3f"; \
	} \
	CASE 5: 		/* C range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".2f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".0f"; \
		CASE	PRESS_UNIT_CODE_PSI:				".2f"; \
		CASE	PRESS_UNIT_CODE_BAR:				".3f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".0f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".0f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".3f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:				".1f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".0f"; \
		CASE	PRESS_UNIT_CODE_ATM:				".3f"; \
		CASE	PRESS_UNIT_CODE_MPA:				".4f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".0f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".2f"; \
		CASE	PRESS_UNIT_CODE_HPA:				".0f"; \
		DEFAULT:	".2f"; \
	} \
	CASE 6: 		/* E range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".4f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".5f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".5f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".4f"; \
		CASE	PRESS_UNIT_CODE_PSI:				".5f"; \
		CASE	PRESS_UNIT_CODE_BAR:				".6f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".3f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".3f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".6f"; \
		CASE	PRESS_UNIT_CODE_PA:				".1f"; \
		CASE	PRESS_UNIT_CODE_KPA:				".4f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".4f"; \
		CASE	PRESS_UNIT_CODE_ATM:				".6f"; \
		CASE	PRESS_UNIT_CODE_MPA:				".6f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".4f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".2f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".5f"; \
		CASE	PRESS_UNIT_CODE_HPA:				".3f"; \
		DEFAULT:	".4f"; \
	} \
	CASE 7: 		/* V range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".1f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".2f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".2f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".0f"; \
		CASE	PRESS_UNIT_CODE_PSI:				".2f"; \
		CASE	PRESS_UNIT_CODE_BAR:				".3f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".0f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".0f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".3f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:				".1f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".0f"; \
		CASE	PRESS_UNIT_CODE_ATM:				".3f"; \
		CASE	PRESS_UNIT_CODE_MPA:				".4f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".1f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".2f"; \
		CASE	PRESS_UNIT_CODE_HPA:				".0f"; \
		DEFAULT:	".3f"; \
	} \
	CASE 8: 		/* D range */ \
	SELECT( sim_pres_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_INHG:			".1f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".1f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f"; \
		CASE	PRESS_UNIT_CODE_MMHG:			".0f"; \
		CASE	PRESS_UNIT_CODE_PSI:				".1f"; \
		CASE	PRESS_UNIT_CODE_BAR:				".2f"; \
		CASE	PRESS_UNIT_CODE_MBAR:			".0f"; \
		CASE	PRESS_UNIT_CODE_GCM2:			".0f"; \
		CASE	PRESS_UNIT_CODE_KGCM2:			".2f"; \
		CASE	PRESS_UNIT_CODE_PA:				".0f"; \
		CASE	PRESS_UNIT_CODE_KPA:				".0f"; \
		CASE	PRESS_UNIT_CODE_TORR:			".0f"; \
		CASE	PRESS_UNIT_CODE_ATM:				".2f"; \
		CASE	PRESS_UNIT_CODE_MPA:				".3f"; \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".0f"; \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".0f"; \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".1f"; \
		CASE	PRESS_UNIT_CODE_HPA:				".0f"; \
		DEFAULT:	".3f"; \
	} \
	DEFAULT:	".4f";\
}\

#define EDIT_SIM_PRESSURE_PRECISION SIM_PRESSURE_PRECISION

#define SIM_SPRESSURE_PRECISION  SELECT( sim_sp_unit ) { \
		CASE	PRESS_UNIT_CODE_INH2O_68DEGF:	".1f";		/* inH2O  @ 68degF */ \
		CASE	PRESS_UNIT_CODE_INHG:			".2f";		/* inHg  @ 0degC */ \
		CASE	PRESS_UNIT_CODE_FTH2O_68DEGF:	".2f";		/* ftH2O  @ 68degF */ \
		CASE	PRESS_UNIT_CODE_MMH2O_68DEGF:	".0f";		/* mmH2O @ 68degF */ \
		CASE	PRESS_UNIT_CODE_MMHG:			".0f";		/* mmHg @ 0degC */ \
		CASE	PRESS_UNIT_CODE_PSI:				".2f";		/* psi */ \
		CASE	PRESS_UNIT_CODE_BAR:				".3f";		/* bar */ \
		CASE	PRESS_UNIT_CODE_MBAR:			".0f";		/* mbar */ \
		CASE	PRESS_UNIT_CODE_GCM2:			".0f";		/* g/cm2 */ \
		CASE	PRESS_UNIT_CODE_KGCM2:			".3f";		/* kg/cm2 */ \
		CASE	PRESS_UNIT_CODE_PA:				".0f";		/* Pa */ \
		CASE	PRESS_UNIT_CODE_KPA:				".1f";		/* kPa */ \
		CASE	PRESS_UNIT_CODE_TORR:			".0f";		/* torr */ \
		CASE	PRESS_UNIT_CODE_ATM:				".3f";		/* atm */ \
		CASE	PRESS_UNIT_CODE_MPA:				".4f";		/* MPa */ \
		CASE	PRESS_UNIT_CODE_INH2O_4DEGC:		".1f";		/* inH2O */ \
		CASE	PRESS_UNIT_CODE_MMH2O_4DEGC:		".0f";		/* mmH2O */ \
		CASE	PRESS_UNIT_CODE_FTH2O_4DEGC:		".2f";		/* ftH2O */ \
		CASE	PRESS_UNIT_CODE_HPA:				".0f";		/* hPa */ \
		DEFAULT:	".4f"; \
}\

#define EDIT_SIM_SPRESSURE_PRECISION SIM_SPRESSURE_PRECISION

/* for METHOD ejx_method_chg_univ_rev */
#define TEST_KEY1_CHG_UNV_REV	 				0x5255	/* test key 1 for change ability of universal revision */
#define TEST_KEY1_NXT_UNV_REV 					0x5255	/* test key 1 for universal revision */
#define TEST_KEY1_NXT_DEV_REV 					0x5255	/* test key 1 for device revision */

#define TEST_KEY2_CHG_UNV_REV					0x01	/* test key 2 for change ability of universal revision */
#define TEST_KEY2_NXT_UNV_REV					0x02	/* test key 2 for universal revision after restart */
#define TEST_KEY2_NXT_DEV_REV					0x03	/* test key 2 for device revision after restart */

#define UNV_CMD_REV5							5		/* universal revision 5 */
#define UNV_CMD_REV7							7		/* universal revision 7 */

#define DEV_REV_MIN								0		/* device revision minimum number */
#define DEV_REV_MAX								100		/* device revision maximum number */

#define UNV_CMD_REV_CHG_CANCEL					1		/* cancel flag for the change done before */
#define UNV_CMD_REV_CHG_UNCACL					0		/* new change for the universal revision  */

#define TEST_KEY4_CHG_UNV_REV_DSA				0		/* device is disable to be changed with universal revision */
#define TEST_KEY4_CHG_UNV_REV_ABL				1		/* device is able to be changed with universal revision */

#define EEP_SIG_AEA_WRT_DLY				    	1		/* unit:s delay time for writing single area of eeprom */

#define TEST_KEY4_UP1_BEF_ABT					0		/* process before abort process */
#define TEST_KEY4_UP1_AFT_ABT					1		/* process after  abort process */

#define TEST_KEY4_UP1_ABT_MAK					0xff00	/* abort flg mask of test_key_4_upper1  */
#define TEST_KEY4_UP1_ABT_SFT					8		/* abort flg bit position at test_key_4_upper1 */

#define TEST_KEY4_UP1_NXT_UNV_REV_MAK			0x00ff	/* next univ rev mask of test_key_4_upper1  */
#define TEST_KEY4_UP1_NXT_UNV_REV_SFT			0		/* next univ rev bit position at test_key_4_upper1 */


/* for METHOD ejx_method_chg_pwon_info */
#define TEST_KEY1_CHG_PWON_INFO_STAT			0x5049	/* test key 1 for the ability of changing power on info */

#define TEST_KEY2_CHG_PWON_INFO_STAT			0x01	/* test key 2 for on/off status  of power on info */

#define TEST_KEY4_CHG_PWON_INFO_STAT_OFF		0		/* power on information OFF */
#define TEST_KEY4_CHG_PWON_INFO_STAT_ON			1		/* power on information ON  */

#define	STR_NOT_SUPPORTED						"This function is not supported."
#define	RTN_SUPPORTED							(0)
#define	RTN_NOT_SUPPORTED						(-1)
